@@ -137,7 +137,7 @@ use MIME::Field::ContType;
 #------------------------------
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.414";
+$VERSION = "5.416";
 
 ### Sanity (we put this test after our own version, for CPAN::):
 use Mail::Header 1.06 ();
@@ -742,16 +742,14 @@ that we remove any trailing spaces:
    must be presumed to have been added by a gateway, and must be deleted.
 
 Returns undef (B<not> the empty string) if either the message is not
-multipart, if there is no specified boundary, or if the boundary is
-illegal (e.g., if it is empty after all trailing whitespace has been
-removed).
+multipart or if there is no specified boundary.
 
 =cut
 
 sub multipart_boundary {
     my $self = shift;
     my $value =  $self->mime_attr('content-type.boundary');
-    (!defined($value) or $value eq '') ? undef : $value;
+    (!defined($value)) ? undef : $value;
 }
 
 #------------------------------
@@ -906,7 +904,7 @@ Lee E. Brotzman, Advanced Data Solutions.
 
 =head1 VERSION
 
-$Revision: 1.6 $ $Date: 2004/10/06 18:55:27 $
+$Revision: 1.10 $ $Date: 2004/12/29 17:50:39 $
 
 =cut
 
