@@ -29,7 +29,7 @@ $ME = "MIME-tools";
 Exporter::export_ok_tags('config', 'msgs', 'msgtypes', 'utils');
 
 # The TOOLKIT version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.415";
+$VERSION = "5.416";
 
 # Configuration (do NOT alter this directly)...
 # All legal CONFIG vars *must* be in here, even if only to be set to undef:
@@ -1025,7 +1025,7 @@ bugs I<before> they become problems...
 
 =head1 VERSION
 
-$Revision: 1.7 $
+$Revision: 1.10 $
 
 
 =head1 CHANGE LOG
@@ -1971,9 +1971,10 @@ Better yet, email me, and I'll put you in.
 
 =head1 SEE ALSO
 
-At the time of this writing ($Date: 2004/10/27 12:44:25 $), the MIME-tools homepage was
-F<http://www.zeegee.com/code/perl/MIME-tools>.
-Check there for updates and support.
+At the time of this writing ($Date: 2005/01/03 15:38:55 $), the
+MIME-tools homepage was
+F<http://www.mimedefang.org/static/mime-tools.php>.  Check there for
+updates and support.
 
 Users of this toolkit may wish to read the documentation of Mail::Header
 and Mail::Internet.
